﻿using System;
using System.Drawing;

using DevExpress.XtraEditors;
using DevExpress.XtraTreeList;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Load                        += Form_Load;
            this.treeList.NodeCellStyle += treeList_NodeCellStyle;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.treeList.RowHeight                              = 25;
            this.treeList.OptionsView.AutoWidth                  = false;
            this.treeList.OptionsBehavior.ReadOnly               = true;
            this.treeList.OptionsBehavior.PopulateServiceColumns = true;
            this.treeList.KeyFieldName                           = "ID";
            this.treeList.ParentFieldName                        = "RegionID";

            this.treeList.DataSource = SalesData.GetSalesDataList();

            this.treeList.Columns[this.treeList.KeyFieldName   ].Visible = false;
            this.treeList.Columns[this.treeList.ParentFieldName].Visible = false;

            this.treeList.BestFitColumns();
        }

        #endregion
        #region 트리 리스트 노드 셀 스타일 설정하기 - treeList_NodeCellStyle(sender, e)

        /// <summary>
        /// 트리 리스트 노드 셀 스타일 설정하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void treeList_NodeCellStyle(object sender, GetCustomNodeCellStyleEventArgs e)
        {
            if(e.Column.FieldName != "Sales")
            {
                return;
            }

            if(Convert.ToDecimal(e.Node.GetValue(e.Column.AbsoluteIndex)) > 20000)
            {
                e.Appearance.BackColor      = Color.FromArgb(80, 255, 0, 255);
                e.Appearance.ForeColor      = Color.White;
                e.Appearance.FontStyleDelta = FontStyle.Bold;
            }
        }

        #endregion
    }
}